==> jaguar_generator-0.4.0.tar.gz: lib/parser/route.dart <==
part of jaguar.generator.parser.route;

class ParsedRoute extends Object with ChainFunction {
  final ParsedUpper upper;

  final MethodElementWrap method;

  final AnnotationElementWrap routeAnnot;

  final List<ParsedInput> inputs;

  final List<ParsedWrapper> interceptors;

  final List<ParsedExceptionHandler> exceptions;

  ant.RouteBase get item => routeAnnot.instantiated;

  String get instantiationString => routeAnnot.instantiationString;

  String get prototype => method.prototype;

  bool get isWebSocket => item is ant.Ws;

  bool get returnsResponse =>
      method.returnTypeWithoutFuture.compareNamedElement(kJaguarResponse);

  DartTypeWrap get jaguarResponseType {
    if (!returnsResponse) {
      return method.returnTypeWithoutFuture;
    }

    return method.returnTypeWithoutFuture.typeArguments.first;
  }

  bool get canHaveQueryParams => true;

  @override
  int get numDefaultInputs =>
      getNumDefaultInputs(needsHttpRequest, isWebSocket);

  ParsedRoute(this.upper, this.method, this.routeAnnot, this.inputs,
      this.interceptors, this.exceptions);

  static int getNumDefaultInputs(bool httpReq, bool isWebSocket) =>
      (httpReq ? 1 : 0) + (isWebSocket ? 1 : 0);
}

class _ParsedRouteBuilder {
  final ParsedUpper upper;

  final MethodElementWrap method;

  ParsedRoute _route;

  ParsedRoute get route => _route;

  final Map<String, bool> _interceptorResultUsed = {};

  dynamic _instantiated;

  int get numDefaultInputs => ParsedRoute.getNumDefaultInputs(
      _needsHttpRequest(method), _instantiated is ant.Ws);

  _ParsedRouteBuilder(this.upper, this.method) {
    List<AnnotationElementWrap> annots = method.metadata
        .where((annot) => annot.instantiated is ant.RouteBase)
        .toList();

    if (annots.length == 0) {
      return;
    }

    if (annots.length != 1) {
      final except = new RouteException(
          'Route method has more than one route annotations!');
      except.upper = upper.name;
      except.route = method.name;
      throw except;
    }

    _instantiated = annots.first.instantiated;

    final List<ParsedInput> inputs = [];
    inputs.addAll(_detectInputs());

    final List<ParsedWrapper> interceptors =
        ParsedWrapper.detectWrappers(upper.upper, method);

    final List<ParsedExceptionHandler> exceptions = [];
    ParsedExceptionHandler.detectAllExceptions(method).forEach(exceptions.add);

    _route = new ParsedRoute(
        upper, method, annots.first, inputs, interceptors, exceptions);
  }

  //Detects inputs
  List<ParsedInput> _detectInputs() {
    final List<ParsedInput> inputs =
        ParsedInput.detectInputs(method, method.parameters, numDefaultInputs);

    final int numMethodInps = numDefaultInputs + inputs.length;
    bool hasFinished = false;

    //Detect inputs on parameters
    for (int idx = numDefaultInputs;
        idx < method.requiredParameters.length;
        idx++) {
      final ParameterElementWrap param = method.requiredParameters[idx];

      ParsedInput input = ParsedInput.detectOnParam(param);

      if (idx < numMethodInps) {
        if (input is ParsedInput) {
          final except = new InputException(
              'Input for this method is already specified on method!');
          except.param = param.name;
          throw except;
        }
        continue;
      }

      if (input is ParsedInput) {
        if (hasFinished) {
          final except = new InputException(
              'Inputs must be specified in consecutive params!');
          except.param = param.name;
          throw except;
        }
        inputs.add(input);
      } else {
        hasFinished = true;
      }
    }

    inputs.forEach((inp) {
      if (inp is ParsedInputInterceptor) {
        _interceptorResultUsed[inp.genName] = true;
      }
    });

    return inputs;
  }
}

==> jaguar_generator-0.5.2.tar.gz: lib/parser/route.dart <==
part of jaguar.generator.parser.route;

class ParsedRoute {
  final ParsedUpper upper;

  final MethodElementWrap method;

  final AnnotationElementWrap routeAnnot;

  final List<Symbol> interceptors;

  final List<ParsedExceptionHandler> exceptions;

  ant.RouteBase get item => routeAnnot.instantiated;

  String get instantiationString => routeAnnot.instantiationString;

  String get prototype => method.prototype;

  bool get returnsResponse =>
      method.returnTypeWithoutFuture.compareNamedElement(kJaguarResponse);

  DartTypeWrap get jaguarResponseType {
    if (!returnsResponse) {
      return method.returnTypeWithoutFuture;
    }

    return method.returnTypeWithoutFuture.typeArguments.first;
  }

  ParsedRoute(this.upper, this.method, this.routeAnnot, this.interceptors,
      this.exceptions);
}

class _ParsedRouteBuilder {
  final ParsedUpper upper;

  final MethodElementWrap method;

  ParsedRoute _route;

  ParsedRoute get route => _route;

  _ParsedRouteBuilder(this.upper, this.method) {
    List<AnnotationElementWrap> annots = method.metadata
        .where((annot) => annot.instantiated is ant.RouteBase)
        .toList();

    if (annots.length == 0) {
      return;
    }

    if (annots.length != 1) {
      final except = new RouteException(
          'Route method has more than one route annotations!');
      except.upper = upper.name;
      except.route = method.name;
      throw except;
    }

    final List<Symbol> interceptors = detectWrappers(upper.upper, method);

    final List<ParsedExceptionHandler> exceptions = [];
    ParsedExceptionHandler.detectAllExceptions(method).forEach(exceptions.add);

    _route =
        new ParsedRoute(upper, method, annots.first, interceptors, exceptions);
  }
}
